|PyPI Version| |Build Status| |Coverage Status|

================
Aldryn Reversion
================


Description
~~~~~~~~~~~

Support for django-reversion on models with translatable fields and django-cms
placeholder fields.


--------------------
Installation & Usage
--------------------


Aldryn Platform Users
~~~~~~~~~~~~~~~~~~~~~

TODO


Manual Installation
~~~~~~~~~~~~~~~~~~~

1) Run `pip install aldryn-reversion`.

2) Add below apps to ``INSTALLED_APPS``: ::

    INSTALLED_APPS = [
        …
        'aldryn_reversion',
        …
    ]

3) (Re-)Start your application server.
